@@ -6,6 +6,7 @@ from typing import Optional
 # Shared properties
 class TraceBase(BaseModel):
     path: Path
+    delimiter: Optional[str]
 
 
 # Properties to receive on Trace creation
@@ -24,9 +25,6 @@ class TraceInDBBase(TraceBase):
     headers_line: str
     last_byte: int
 
-    class Config:
-        orm_mode = True
-
 
 # Properties to return to client
 class Trace(TraceInDBBase):
